@@ -1,6 +1,6 @@
 /*
  * conn.c
- * $Id: conn.c,v 1.49 2006/04/20 16:39:46 ianmacd Exp $
+ * $Id: conn.c,v 1.51 2006/08/01 00:07:53 ianmacd Exp $
  */
 
 #include "ruby.h"
@@ -1049,7 +1049,7 @@ rb_ldap_conn_search_s (int argc, VALUE argv[], VALUE self)
  * conn.search2(base_dn, scope, filter, attrs=nil, attrsonly=false,
  *		sec=0, usec=0, s_attr=nil, s_proc=nil)  => array
  * conn.search2(base_dn, scope, filter, attrs=nil, attrsonly=false,
- *		sec=0, usec=0, s_attr=nil, s_proc=nil) { |entry| }  => self
+ *		sec=0, usec=0, s_attr=nil, s_proc=nil) { |entry_as_hash| }  => self
  *
  * Perform a search, with the base DN +base_dn+, a scope of +scope+ and a
  * search filter of +filter+.
@@ -1292,7 +1292,7 @@ rb_ldap_conn_search_ext_s (int argc, VALUE argv[], VALUE self)
  *                  s_attr=nil, s_proc=nil)  => array
  * conn.search_ext2(base_dn, scope, filter, attrs=nil,
  *                  attrsonly=false, sctrls, cctrls, sec=0, usec=0,
- *                  s_attr=nil, s_proc=nil) { |entry| }  => self
+ *                  s_attr=nil, s_proc=nil) { |entry_as_hash| }  => self
  *
  * Perform a search, with the base DN +base_dn+, a scope of +scope+ and a
  * search filter of +filter+.
@@ -1459,9 +1459,9 @@ rb_ldap_conn_add_ext_s (VALUE self, VALUE dn, VALUE attrs,
 
 /*
  * call-seq:
- * conn.modify(dn, attrs)  => self
+ * conn.modify(dn, mods)  => self
  *
- * Modify an entry with the DN, +dn+, and the attributes, +attrs+. +attrs+
+ * Modify an entry with the DN, +dn+, and the attributes, +mods+. +mods+
  * should be either an array of LDAP#Mod objects or a hash of attribute/value
  * array pairs.
  */
@@ -1510,9 +1510,9 @@ rb_ldap_conn_modify_s (VALUE self, VALUE dn, VALUE attrs)
 #if defined(HAVE_LDAPCONTROL) && defined(HAVE_LDAP_MODIFY_EXT_S)
 /*
  * call-seq:
- * conn.modify_ext(dn, attrs, sctrls, cctrls)  => self
+ * conn.modify_ext(dn, mods, sctrls, cctrls)  => self
  *
- * Modify an entry with the DN, +dn+, and the attributes, +attrs+. +attrs+
+ * Modify an entry with the DN, +dn+, and the attributes, +mods+. +mods+
  * should be either an array of LDAP#Mod objects or a hash of attribute/value
  * array pairs. +sctrls+ is an array of server controls, whilst +cctrls+ is
  * an array of client controls.
